@@ -46,7 +46,6 @@ ephy_history_service_initialize_hosts_table (EphyHistoryService *self)
     g_error_free (error);
     return FALSE;
   }
-  ephy_history_service_schedule_commit (self);
   return TRUE;
 }
 
@@ -410,7 +409,8 @@ ephy_history_service_get_host_row_from_url (EphyHistoryService *self,
 
   if (host == NULL) {
     host = ephy_history_host_new (host_locations->data, hostname, 0, 1.0);
-    ephy_history_service_add_host_row (self, host);
+    if (!self->read_only)
+      ephy_history_service_add_host_row (self, host);
   }
 
   g_free (hostname);
@@ -424,7 +424,7 @@ ephy_history_service_delete_host_row (EphyHistoryService *self,
                                       EphyHistoryHost    *host)
 {
   EphySQLiteStatement *statement = NULL;
-  gchar *sql_statement;
+  const char *sql_statement;
   GError *error = NULL;
 
   g_assert (self->history_thread == g_thread_self ());
@@ -433,13 +433,12 @@ ephy_history_service_delete_host_row (EphyHistoryService *self,
   g_assert (host->id != -1 || host->url);
 
   if (host->id != -1)
-    sql_statement = g_strdup ("DELETE FROM hosts WHERE id=?");
+    sql_statement = "DELETE FROM hosts WHERE id=?";
   else
-    sql_statement = g_strdup ("DELETE FROM hosts WHERE url=?");
+    sql_statement = "DELETE FROM hosts WHERE url=?";
 
   statement = ephy_sqlite_connection_create_statement (self->history_database,
                                                        sql_statement, &error);
-  g_free (sql_statement);
 
   if (error) {
     g_warning ("Could not build urls table query statement: %s", error->message);
