@@ -22,6 +22,7 @@
 
 #include "ephy-bookmark.h"
 
+#include <glib/gi18n.h>
 #include <gio/gio.h>
 
 G_BEGIN_DECLS
@@ -30,6 +31,8 @@ G_BEGIN_DECLS
 
 G_DECLARE_FINAL_TYPE (EphyBookmarksManager, ephy_bookmarks_manager, EPHY, BOOKMARKS_MANAGER, GObject)
 
+#define EPHY_BOOKMARKS_FAVORITES_TAG N_("Favorites")
+
 EphyBookmarksManager *ephy_bookmarks_manager_new                  (void);
 
 void         ephy_bookmarks_manager_add_bookmark                  (EphyBookmarksManager *self,
@@ -53,7 +56,6 @@ gboolean     ephy_bookmarks_manager_tag_exists                    (EphyBookmarks
 GSequence   *ephy_bookmarks_manager_get_bookmarks                 (EphyBookmarksManager *self);
 GSequence   *ephy_bookmarks_manager_get_bookmarks_with_tag        (EphyBookmarksManager *self,
                                                                    const char           *tag);
-GSequence   *ephy_bookmarks_manager_get_smart_bookmarks           (EphyBookmarksManager *self);
 GSequence   *ephy_bookmarks_manager_get_tags                      (EphyBookmarksManager *self);
 
 void        ephy_bookmarks_manager_save_to_file_async             (EphyBookmarksManager *self,
